==> haskell-prettyprinter-1.3.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.3.0
id: prettyprinter-1.3.0-Hk7YxusyFZ4CBPO5K9XlPv
key: prettyprinter-1.3.0-Hk7YxusyFZ4CBPO5K9XlPv
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: 602c765603a0012d120ab55ef0a3c17d
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-1.3.0
hs-libraries: HSprettyprinter-1.3.0-Hk7YxusyFZ4CBPO5K9XlPv
depends:
    base-4.12.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-1.3.0-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.3.0
id: prettyprinter-1.3.0-3u02md8VEVp8epybMM46tV
key: prettyprinter-1.3.0-3u02md8VEVp8epybMM46tV
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: bf29b83c370278e2cc1780f817fe1c9c
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-1.3.0
hs-libraries: HSprettyprinter-1.3.0-3u02md8VEVp8epybMM46tV
depends:
    base-4.12.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
